==> hastymail-1.5_2.tbz: www/hastymail/lib/constant.php <==
<?php

/* constant.php: some constants used in many hastymail pages.
*
    Copyright (C) 2002-2005  Hastymail Development group

    This file is part of Hastymail.

    Hastymail is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Hastymail is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Hastymail; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

* $Id: constant.php,v 1.63 2006/02/16 21:52:46 sailfrog Exp $
*/

/* absolute path to the configuration file */
$config_file = '/etc/hastymail.conf';

/* hastymail version */
$version = '1.5';

/* key for hastymail's encryption */
$hasty_key = 'You should be using the more secure version!';

/* default toolbar setup. To remove pages from hastymail change the
   value to false (note thats false with no quotes) */

$toolbar_defaults = array(
    'search'           => true,          /* search page         */
    'folders'          => true,          /* folders page        */
    'contacts'         => true,          /* contacts page       */
    'compose'          => true,          /* compose page        */
    'options'          => true,          /* options page        */
    'new'              => true,           /* new mail page       */
    'new_session'      => false           /* change session id   */
    );

/* default user settings. Notice that booleans and strings
   are single quoted, but numbers are not */

$defaults = array(
    'lang'             => 'en_US',       /* interface language                        */
    'page_count'       => 20,            /* messages per page                         */
    'read_wrap'        => 70,            /* wrap length for incoming text             */
    'refresh_new'      => 5,             /* new page refresh rate (minutes)           */ 
    'start_page'       => 'mailbox.php', /* first displayed page                      */
    'filter_level'     => 1,             /* HTML filter level, options are:
                                                1 = default level, no images, no links
                                                2 = images only
                                                3 = links only
                                                4 = links and images                  */
    'simple'           => 'false',       /* simple mode                               */
    'click_links'      => 'false',       /* clickable links in text parts             */
    'click_email'      => 'false',       /* clickable emails in text parts            */
    'wrap_clean'       => 'true',       /* show '\' on wrapped lines                 */
    'html_only'        => 'false',       /* display html parts if no text part exists */
    'font_type'        => 'monospace',   /* text part font family                     */
    'folder_detail'    => 'new',         /* detail level on folder list               */
    'date_format'      => 'm/d/y',       /* date format string, options are:
                                                m/d/y    =  mm/dd/yy
                                                m/d/Y    =  mm/dd/yyyy
                                                m-d-y    =  mm-dd-yy
                                                m/d/Y    =  mm-dd-yyyy
                                                M j, Y   =  mon dd, yyyy
                                                M j, y   =  mon dd, yy
                                                M j      =  mon dd   
                                                F d, Y   =  month dd, yyyy
                                                F d, y   =  month dd, yy
                                                r        =  rfc822
                                                d/m/Y    =  dd/mm/yyyy 
                                                d/m/y    =  dd/mm/yy
                                                Y-m-d    =  yyyy-mm-dd
                                                y-m-d    =  yy-mm-dd                  */
    'time_format'      => 'g:i a',     /* time format string, options are:
                                                g:i:s a = 12:00:00
                                                G:i:s   = 24:00:00
                                                g:i a   = 12:00
                                                G:i     = 24:00                       */
    'folder_style'     => 'nested',      /* folder list style (nested or flat)        */
    'html_default'     => 'true',        /* show html parts by default (blech!)       */
    'folder_preview'   => 'none',        /* folder preview option                     */
    'preview_position' => 0,             /* folder preview position (0=top, 1=bottom) */
    'profile_count'    => 1,             /* default profile count. DONT CHANGE THIS   */
    'refresh_new'      => 0,             /* default refresh interval for new page     */
    'font_size'        => 11,            /* interface font size in pts                */
    );

/* viewable message parts. This should be the MIME type and subtype
   for the file.  if present in this list a "view" link will be availble next
   to that type of attachment */

$message_part_types = array( 
    'messagedisposition-notification',   /* text part for MDN                       */
    'messagedelivery-status',            /* text part for message bounce            */
    'messagerfc822-headers',             /* text part for message headers           */
    'textplain',                         /* normal text message                     */
    'texthtml',                          /* HTML message (blech)                    */
    'textenriched',                      /* enriched text                           */
    'textrfc822-headers',                /* another text part for message headers   */
    'imagejpeg',                         /* JPEG images                             */
    'imagepjpeg',                        /* JPEG images                             */
    'imagejpg',                          /* JPEG images                             */
    'imagepng',                          /* PNG images                              */
    'imagebmp',                          /* BMP images                              */
    'imagegif',                          /* GIF images                              */
    'applicationpgp-signature',          /* PGP signatures                          */
    );

/* available dictionaries for spellchecking */
$dicts = array(
    'en_US' => 'English',
    'fr_FR' => 'French',
    );

?>

==> hastymail-1.5_3.tbz: www/hastymail/lib/constant.php <==
<?php

/* constant.php: some constants used in many hastymail pages.
*
    Copyright (C) 2002-2005  Hastymail Development group

    This file is part of Hastymail.

    Hastymail is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Hastymail is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Hastymail; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

* $Id: constant.php,v 1.63 2006/02/16 21:52:46 sailfrog Exp $
*/

/* absolute path to the configuration file */
$config_file = '/usr/local/etc/hastymail.conf';

/* hastymail version */
$version = '1.5';

/* key for hastymail's encryption */
$hasty_key = 'You should be using the more secure version!';

/* default toolbar setup. To remove pages from hastymail change the
   value to false (note thats false with no quotes) */

$toolbar_defaults = array(
    'search'           => true,          /* search page         */
    'folders'          => true,          /* folders page        */
    'contacts'         => true,          /* contacts page       */
    'compose'          => true,          /* compose page        */
    'options'          => true,          /* options page        */
    'new'              => true,           /* new mail page       */
    'new_session'      => false           /* change session id   */
    );

/* default user settings. Notice that booleans and strings
   are single quoted, but numbers are not */

$defaults = array(
    'lang'             => 'en_US',       /* interface language                        */
    'page_count'       => 20,            /* messages per page                         */
    'read_wrap'        => 70,            /* wrap length for incoming text             */
    'refresh_new'      => 5,             /* new page refresh rate (minutes)           */ 
    'start_page'       => 'mailbox.php', /* first displayed page                      */
    'filter_level'     => 1,             /* HTML filter level, options are:
                                                1 = default level, no images, no links
                                                2 = images only
                                                3 = links only
                                                4 = links and images                  */
    'simple'           => 'false',       /* simple mode                               */
    'click_links'      => 'false',       /* clickable links in text parts             */
    'click_email'      => 'false',       /* clickable emails in text parts            */
    'wrap_clean'       => 'true',       /* show '\' on wrapped lines                 */
    'html_only'        => 'false',       /* display html parts if no text part exists */
    'font_type'        => 'monospace',   /* text part font family                     */
    'folder_detail'    => 'new',         /* detail level on folder list               */
    'date_format'      => 'm/d/y',       /* date format string, options are:
                                                m/d/y    =  mm/dd/yy
                                                m/d/Y    =  mm/dd/yyyy
                                                m-d-y    =  mm-dd-yy
                                                m/d/Y    =  mm-dd-yyyy
                                                M j, Y   =  mon dd, yyyy
                                                M j, y   =  mon dd, yy
                                                M j      =  mon dd   
                                                F d, Y   =  month dd, yyyy
                                                F d, y   =  month dd, yy
                                                r        =  rfc822
                                                d/m/Y    =  dd/mm/yyyy 
                                                d/m/y    =  dd/mm/yy
                                                Y-m-d    =  yyyy-mm-dd
                                                y-m-d    =  yy-mm-dd                  */
    'time_format'      => 'g:i a',     /* time format string, options are:
                                                g:i:s a = 12:00:00
                                                G:i:s   = 24:00:00
                                                g:i a   = 12:00
                                                G:i     = 24:00                       */
    'folder_style'     => 'nested',      /* folder list style (nested or flat)        */
    'html_default'     => 'true',        /* show html parts by default (blech!)       */
    'folder_preview'   => 'none',        /* folder preview option                     */
    'preview_position' => 0,             /* folder preview position (0=top, 1=bottom) */
    'profile_count'    => 1,             /* default profile count. DONT CHANGE THIS   */
    'refresh_new'      => 0,             /* default refresh interval for new page     */
    'font_size'        => 11,            /* interface font size in pts                */
    );

/* viewable message parts. This should be the MIME type and subtype
   for the file.  if present in this list a "view" link will be availble next
   to that type of attachment */

$message_part_types = array( 
    'messagedisposition-notification',   /* text part for MDN                       */
    'messagedelivery-status',            /* text part for message bounce            */
    'messagerfc822-headers',             /* text part for message headers           */
    'textplain',                         /* normal text message                     */
    'texthtml',                          /* HTML message (blech)                    */
    'textenriched',                      /* enriched text                           */
    'textrfc822-headers',                /* another text part for message headers   */
    'imagejpeg',                         /* JPEG images                             */
    'imagepjpeg',                        /* JPEG images                             */
    'imagejpg',                          /* JPEG images                             */
    'imagepng',                          /* PNG images                              */
    'imagebmp',                          /* BMP images                              */
    'imagegif',                          /* GIF images                              */
    'applicationpgp-signature',          /* PGP signatures                          */
    );

/* available dictionaries for spellchecking */
$dicts = array(
    'en_US' => 'English',
    'fr_FR' => 'French',
    );

?>
